@@ -40,7 +40,7 @@ QDataStream &operator<<(QDataStream &s, const MailSummary &d)
     s << d.from();
     s << d.to();
     QDateTime tempTime;
-    tempTime.setTime_t(d.date());
+    tempTime.setSecsSinceEpoch(d.date());
     s << tempTime;
     return s;
 }
@@ -57,7 +57,7 @@ QDataStream &operator>>(QDataStream &s, MailSummary &d)
     s >> to;
     QDateTime tempTime;
     s >> tempTime;
-    date = QDateTime(tempTime).toTime_t();
+    date = QDateTime(tempTime).toSecsSinceEpoch();
     d.set(serialNumber, messageId, subject, from, to, date);
     return s;
 }
@@ -189,7 +189,7 @@ MailList MailList::decode(const QByteArray &payload)
     MailList mailList;
     // A read-only data stream
     QDataStream stream(payload);
-    if (payload.size()) {
+    if (!payload.isEmpty()) {
         stream >> mailList;
     }
     return mailList;
@@ -198,7 +198,7 @@ MailList MailList::decode(const QByteArray &payload)
 QByteArray MailList::serialsFromMimeData(const QMimeData *md)
 {
     MailList mailList = fromMimeData(md);
-    if (mailList.count()) {
+    if (!mailList.isEmpty()) {
         MailList::const_iterator it;
         QByteArray a;
         QBuffer buffer(&a);
