@@ -26,7 +26,7 @@
 #include "libkdepim_debug.h"
 #include <KLocalizedString>
 
-namespace KPIM {
+using namespace KPIM;
 unsigned int KPIM::ProgressManager::uID = 42;
 
 ProgressItem::ProgressItem(ProgressItem *parent, const QString &id, const QString &label, const QString &status, bool canBeCanceled, CryptoStatus cryptoStatus)
@@ -218,11 +218,11 @@ unsigned int ProgressItem::progress() const
 
 // ======================================
 
-struct ProgressManagerPrivate {
+struct KPIM::ProgressManagerPrivate {
     ProgressManager instance;
 };
 
-Q_GLOBAL_STATIC(ProgressManagerPrivate, progressManagerPrivate)
+Q_GLOBAL_STATIC(KPIM::ProgressManagerPrivate, progressManagerPrivate)
 
 ProgressManager::ProgressManager()
     : QObject()
@@ -278,8 +278,7 @@ ProgressItem *ProgressManager::createProgressItem(unsigned int progressType, con
                                               QString(), true, KPIM::ProgressItem::Unencrypted, progressType);
 }
 
-ProgressItem *ProgressManager::createProgressItemImpl(ProgressItem *parent, const QString &id, const QString &label, const QString &status, bool cancellable, ProgressItem::CryptoStatus cryptoStatus,
-                                                      unsigned int progressType)
+ProgressItem *ProgressManager::createProgressItemImpl(ProgressItem *parent, const QString &id, const QString &label, const QString &status, bool cancellable, ProgressItem::CryptoStatus cryptoStatus, unsigned int progressType)
 {
     ProgressItem *t = nullptr;
     if (!mTransactions.value(id)) {
@@ -318,8 +317,7 @@ ProgressItem *ProgressManager::createProgressItemImpl(ProgressItem *parent, cons
     return t;
 }
 
-ProgressItem *ProgressManager::createProgressItemImpl(const QString &parent, const QString &id, const QString &label, const QString &status, bool canBeCanceled,
-                                                      ProgressItem::CryptoStatus cryptoStatus, unsigned int progressType)
+ProgressItem *ProgressManager::createProgressItemImpl(const QString &parent, const QString &id, const QString &label, const QString &status, bool canBeCanceled, ProgressItem::CryptoStatus cryptoStatus, unsigned int progressType)
 {
     ProgressItem *p = mTransactions.value(parent);
     return createProgressItemImpl(p, id, label, status, canBeCanceled, cryptoStatus, progressType);
@@ -408,4 +406,3 @@ unsigned int ProgressItem::completedItems() const
 {
     return mCompleted;
 }
-} // namespace
