@@ -138,7 +138,7 @@ KCheckComboBox::KCheckComboBox(QWidget *parent)
     : KComboBox(parent)
     , d(new KCheckComboBox::Private(this))
 {
-    connect(this, QOverload<int>::of(&KComboBox::activated), this, [this]() {
+    connect(this, qOverload<int>(&KComboBox::activated), this, [this]() {
         d->toggleCheckState();
     });
     connect(model(), &QAbstractItemModel::rowsInserted, this,
@@ -149,7 +149,6 @@ KCheckComboBox::KCheckComboBox(QWidget *parent)
         d->updateCheckedItems(topLeft, bottomRight);
     });
 
-
     // read-only contents
     setEditable(true);
 
@@ -368,4 +367,9 @@ void KCheckComboBox::setAlwaysShowDefaultText(bool always)
     }
 }
 
+void KCheckComboBox::updateCheckedItems(const QModelIndex &topLeft, const QModelIndex &bottomRight, int role)
+{
+    d->updateCheckedItems(topLeft, bottomRight, role);
+}
+
 #include "moc_kcheckcombobox.cpp"
