@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,17 +26,20 @@ class Session;
 
 namespace KPIM {
 class AddresseeLineEditManager;
+/**
+ * @brief The AddresseeLineEditAkonadi class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class AddresseeLineEditAkonadi
 {
 public:
-    explicit AddresseeLineEditAkonadi(AddresseeLineEditManager *addressLineStatic);
+    explicit AddresseeLineEditAkonadi();
     ~AddresseeLineEditAkonadi();
 
     Akonadi::Session *akonadiSession() const;
 
 private:
     mutable Akonadi::Session *m_akonadiSession = nullptr;
-    AddresseeLineEditManager *mAddressLineStatic = nullptr;
 };
 }
 
