@@ -22,7 +22,7 @@
 
 #include "kdepimakonadi_export.h"
 
-#include <kjob.h>
+#include <KJob>
 
 namespace Akonadi {
 }
@@ -52,7 +52,7 @@ public:
     /**
      * Destroys the open email address job.
      */
-    ~OpenEmailAddressJob();
+    ~OpenEmailAddressJob() override;
 
     /**
      * Starts the job.
@@ -63,9 +63,6 @@ private:
     //@cond PRIVATE
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void slotSearchDone(KJob *))
-    Q_PRIVATE_SLOT(d, void slotAddContactDone(KJob *))
     //@endcond
 };
 }
